@@ -46,7 +46,8 @@ predict.multnet <-
   if (type == "coefficients")
     return(nbeta)
   if (type == "nonzero")
-    if(object$grouped)return(nonzeroCoef(object$beta[[1]],bystep=TRUE))
+#    if(object$grouped)return(nonzeroCoef(object$beta[[1]],bystep=TRUE))
+    if(object$grouped)return(nonzeroCoef(nbeta[[1]],bystep=TRUE))
     else
       return(lapply(nbeta, function(x) nonzeroCoef(x[-1, ,
                                                    drop = FALSE], bystep = TRUE)))
